require 'mechanize'

module Screenshots
  class Page
    attr_reader :url, :title, :screenshot_name, :screenshot_url

    def initialize(url)
      @url = url
      @screenshot_name = generate_screenshot_name(@url)
      @blog_assets_url = Screenshots.configuration.blog_assets_url
      @screenshot_extension = Screenshots.configuration.image_extension

      agent = Mechanize.new
      agent.get(@url) do |page|
        @title = page.title
      end
    end

    def generate_blog_section
      section = "<h2><a href=\"#{@url}\" title=\"#{@title}\">#{@title}</a></h2>\n"
      section += "<a href=\"#{@url}\">"
      section += "<img src=\"#{screenshot_url}\" alt=\"#{@title}\" title=\"#{@title}\" />"
      section += "</a>\n"
    end

    def screenshot_url
      @screenshot_url ||= File.join(@blog_assets_url, @screenshot_name + "." + @screenshot_extension)
    end

    private

    def generate_screenshot_name(url)
      url.gsub(/(\:\/)*\//, '_')
         .gsub(/[\?=\+\\&]/, '_')
    end
  end
end
